@@ -26,8 +26,9 @@ def unicode_dammit(s, encoding="UTF-8"):
 
     """
     if not isinstance(s, str):
-        raise TypeError("You gave me something besides a str.")
-    return s.decode(encoding, errors='repr')
+        raise TypeError("I got %s, but I want <type 'str'>." % s.__class__)
+    errors = 'repr'
+    return s.decode(encoding, errors)
 
 def ascii_dammit(s):
     """Given a bytestring, return a bytestring.
